@@ -1,10 +1,10 @@
 
 /* Compiler implementation of the D programming language
- * Copyright (C) 2017-2021 by The D Language Foundation, All Rights Reserved
+ * Copyright (C) 2017-2022 by The D Language Foundation, All Rights Reserved
  * written by Walter Bright
- * http://www.digitalmars.com
+ * https://www.digitalmars.com
  * Distributed under the Boost Software License, Version 1.0.
- * http://www.boost.org/LICENSE_1_0.txt
+ * https://www.boost.org/LICENSE_1_0.txt
  * https://github.com/dlang/dmd/blob/master/src/dmd/id.h
  */
 
@@ -56,9 +56,6 @@ struct Id
     static Identifier *ctfe;
     static Identifier *_arguments;
     static Identifier *_argptr;
-    static Identifier *builtin_va_start;
-    static Identifier *builtin_va_copy;
-    static Identifier *builtin_va_end;
     static Identifier *LDC_intrinsic;
     static Identifier *LDC_global_crt_ctor;
     static Identifier *LDC_global_crt_dtor;
