@@ -79,12 +79,10 @@ public:
     FileName objfile;   // output .obj file
     FileName hdrfile;   // 'header' file
     FileName docfile;   // output documentation file
-    FileBuffer *srcBuffer; // set during load(), free'd in parse()
+    DArray<unsigned char> src; // Raw content of the file
     unsigned errors;    // if any errors in file
     unsigned numlines;  // number of lines in source file
-    bool isHdrFile;     // if it is a header (.di) file
-    bool isCFile;       // if it is a C (.c) file
-    bool isDocFile;     // if it is a documentation input file, not D source
+    FileType filetype;  // source file type
     bool hasAlwaysInlines; // contains references to functions that must be inlined
     bool isPackageFile; // if it is a package.d
     Package *pkg;       // if isPackageFile is true, the Package that contains this package.d
