@@ -15,7 +15,6 @@
 #include "gen/abi-aarch64.h"
 
 #include "dmd/identifier.h"
-#include "dmd/ldcbindings.h"
 #include "dmd/nspace.h"
 #include "gen/abi.h"
 #include "gen/abi-generic.h"
@@ -60,7 +59,7 @@ public:
     }
 
     Type *rt = tf->next->toBasetype();
-    if (rt->ty == Tstruct || rt->ty == Tsarray) {
+    if (rt->ty == TY::Tstruct || rt->ty == TY::Tsarray) {
       auto argTypes = getArgTypes(rt);
       return !argTypes // FIXME: get rid of sret workaround for 0-sized return
                        //        values (static arrays with 0 elements)
@@ -70,10 +69,23 @@ public:
     return false;
   }
 
+  // Prefer a ref if the POD cannot be passed in registers, i.e., if
+  // IndirectByvalRewrite would be applied.
+  bool preferPassByRef(Type *t) override {
+    t = t->toBasetype();
+
+    if (!(t->ty == TY::Tstruct || t->ty == TY::Tsarray))
+      return false;
+
+    auto argTypes = getArgTypes(t);
+    return argTypes // not 0-sized
+        && argTypes->arguments->empty(); // cannot be passed in registers
+  }
+
   bool passByVal(TypeFunction *, Type *) override { return false; }
 
   void rewriteFunctionType(IrFuncTy &fty) override {
-    if (!fty.ret->byref && fty.ret->type->toBasetype()->ty != Tvoid) {
+    if (!skipReturnValueRewrite(fty)) {
       rewriteArgument(fty, *fty.ret, /*isReturnVal=*/true);
     }
 
@@ -161,7 +173,7 @@ public:
     // using TypeIdentifier here is a bit wonky but works, as long as the name
     // is actually available in the scope (this is what DMD does, so if a
     // better solution is found there, this should be adapted).
-    return createTypeIdentifier(Loc(), Identifier::idPool("__va_list"));
+    return TypeIdentifier::create(Loc(), Identifier::idPool("__va_list"));
   }
 
   const char *objcMsgSendFunc(Type *ret, IrFuncTy &fty) override {
