@@ -16,19 +16,17 @@
 
 struct SPIRVTargetABI : TargetABI {
   DComputePointerRewrite pointerRewite;
-  llvm::CallingConv::ID callingConv(LINK l, TypeFunction *tf = nullptr,
-                                    FuncDeclaration *fdecl = nullptr) override {
-    assert(fdecl);
-    if (hasKernelAttr(fdecl))
-      return llvm::CallingConv::SPIR_KERNEL;
-    else
-      return llvm::CallingConv::SPIR_FUNC;
+  llvm::CallingConv::ID callingConv(LINK) override {
+    llvm_unreachable("expected FuncDeclaration overload to be used");
+  }
+  llvm::CallingConv::ID callingConv(FuncDeclaration *fdecl) override {
+    return hasKernelAttr(fdecl) ? llvm::CallingConv::SPIR_KERNEL
+                                : llvm::CallingConv::SPIR_FUNC;
   }
   bool passByVal(TypeFunction *, Type *t) override {
     t = t->toBasetype();
     return ((t->ty == TY::Tsarray || t->ty == TY::Tstruct) && t->size() > 64);
   }
-  bool reverseExplicitParams(TypeFunction *) override { return false; }
   void rewriteFunctionType(IrFuncTy &fty) override {
     for (auto arg : fty.args) {
       if (!arg->byref)
