@@ -80,10 +80,14 @@ struct TargetABI {
 
   /// Returns the LLVM calling convention to be used for the given D linkage
   /// type on the target. Defaults to the C calling convention.
-  virtual llvm::CallingConv::ID callingConv(LINK l, TypeFunction *tf = nullptr,
-                                            FuncDeclaration *fdecl = nullptr) {
+  virtual llvm::CallingConv::ID callingConv(LINK) {
     return llvm::CallingConv::C;
   }
+  // By default, enforce C calling convention for (non-typesafe) variadics,
+  // otherwise forward to LINK overload.
+  virtual llvm::CallingConv::ID callingConv(TypeFunction *tf, bool withThisPtr);
+  // By default, forward to TypeFunction overload.
+  virtual llvm::CallingConv::ID callingConv(FuncDeclaration *fdecl);
 
   /// Applies any rewrites that might be required to accurately reproduce the
   /// passed function name on LLVM given a specific calling convention.
@@ -143,11 +147,6 @@ struct TargetABI {
   /// argument.
   virtual bool passThisBeforeSret(TypeFunction *tf) { return false; }
 
-  /// Returns true if the explicit parameters order is to be reversed.
-  /// Defaults to true for non-variadic extern(D) functions as required by
-  /// druntime.
-  virtual bool reverseExplicitParams(TypeFunction *tf);
-
   /// Called to give ABI the chance to rewrite the types
   virtual void rewriteFunctionType(IrFuncTy &fty) = 0;
   virtual void rewriteVarargs(IrFuncTy &fty, std::vector<IrFuncTyArg *> &args);
