@@ -51,11 +51,7 @@ void emitCoverageLinecountInc(const Loc &loc) {
   case opts::CoverageIncrement::nonatomic: {
     // Do a non-atomic increment, user is responsible for correct results with
     // multithreaded execution
-    llvm::LoadInst *load = gIR->ir->CreateAlignedLoad(
-#if LDC_LLVM_VER >= 800
-        i32Type,
-#endif
-        ptr, LLAlign(4));
+    llvm::LoadInst *load = gIR->ir->CreateAlignedLoad(i32Type, ptr, LLAlign(4));
     llvm::StoreInst *store = gIR->ir->CreateAlignedStore(
         gIR->ir->CreateAdd(load, DtoConstUint(1)), ptr, LLAlign(4));
     // add !nontemporal attribute, to inform the optimizer that caching is not
