@@ -17,6 +17,7 @@
 #include "dmd/init.h"
 #include "dmd/nspace.h"
 #include "dmd/root/rmem.h"
+#include "dmd/target.h"
 #include "dmd/template.h"
 #include "driver/cl_options.h"
 #include "gen/classes.h"
@@ -230,7 +231,7 @@ public:
 
     for (auto o : *decl->objects) {
       DsymbolExp *exp = static_cast<DsymbolExp *>(o);
-      assert(exp->op == TOKdsymbol);
+      assert(exp->op == EXP::dSymbol);
       exp->s->accept(this);
     }
   }
@@ -318,8 +319,15 @@ public:
       return;
     }
 
-    // FIXME: This is #673 all over again.
-    if (!global.params.linkonceTemplates && !decl->needsCodegen()) {
+    // With -linkonce-templates-aggressive, only non-speculative instances make
+    // it to module members (see `TemplateInstance.appendToModuleMember()`), and
+    // we don't need full needsCodegen() culling in that case; isDiscardable()
+    // is sufficient. Speculative ones are lazily emitted if actually referenced
+    // during codegen - per IR module.
+    if ((global.params.linkonceTemplates == LinkonceTemplates::aggressive &&
+         decl->isDiscardable()) ||
+        (global.params.linkonceTemplates != LinkonceTemplates::aggressive &&
+         !decl->needsCodegen())) {
       Logger::println("Does not need codegen, skipping.");
       return;
     }
@@ -435,7 +443,7 @@ public:
       }
     } else if (decl->ident == Id::linkerDirective) {
       // embed in object file (if supported)
-      if (triple.isWindowsMSVCEnvironment() || triple.isOSBinFormatMachO()) {
+      if (target.supportsLinkerDirective()) {
         assert(decl->args);
         llvm::SmallVector<llvm::StringRef, 2> args;
         args.reserve(decl->args->length);
