@@ -15,7 +15,6 @@
 #pragma once
 
 #include "dmd/aggregate.h"
-#include "dmd/root/root.h"
 #include "gen/dibuilder.h"
 #include "gen/objcgen.h"
 #include "ir/iraggr.h"
@@ -267,6 +266,8 @@ public:
   void addLinkerOption(llvm::ArrayRef<llvm::StringRef> options);
   void addLinkerDependentLib(llvm::StringRef libraryName);
 
+  llvm::CallInst *createInlineAsmCall(const Loc &loc, llvm::InlineAsm *ia,
+                                      llvm::ArrayRef<llvm::Value *> args);
   void addInlineAsmSrcLoc(const Loc &loc, llvm::CallInst *inlineAsmCall);
   const Loc &getInlineAsmSrcLoc(unsigned srcLocCookie) const;
 
