@@ -392,6 +392,11 @@ void DtoAssign(const Loc &loc, DValue *lhs, DValue *rhs, EXP op,
   Type *t = lhs->type->toBasetype();
   assert(t->ty != TY::Tvoid && "Cannot assign values of type void.");
 
+  if (t->ty == TY::Tnoreturn) {
+    // nothing to assign
+    return;
+  }
+
   if (t->ty == TY::Tbool) {
     DtoStoreZextI8(DtoRVal(rhs), DtoLVal(lhs));
   } else if (t->ty == TY::Tstruct) {
@@ -766,58 +771,45 @@ DValue *DtoPaintType(const Loc &loc, DValue *val, Type *to) {
   IF_LOG Logger::println("repainting from '%s' to '%s'", from->toChars(),
                          to->toChars());
 
-  if (from->ty == TY::Tarray) {
-    Type *at = to->toBasetype();
-    assert(at->ty == TY::Tarray);
-    Type *elem = at->nextOf()->pointerTo();
-    if (DSliceValue *slice = val->isSlice()) {
-      return new DSliceValue(to, slice->getLength(),
-                             DtoBitCast(slice->getPtr(), DtoType(elem)));
-    }
-    if (val->isLVal()) {
-      LLValue *ptr = DtoLVal(val);
-      ptr = DtoBitCast(ptr, DtoType(at->pointerTo()));
-      return new DLValue(to, ptr);
-    }
-    LLValue *len, *ptr;
-    len = DtoArrayLen(val);
-    ptr = DtoArrayPtr(val);
-    ptr = DtoBitCast(ptr, DtoType(elem));
-    return new DImValue(to, DtoAggrPair(len, ptr));
-  }
-  if (from->ty == TY::Tdelegate) {
-    Type *dgty = to->toBasetype();
-    assert(dgty->ty == TY::Tdelegate);
-    if (val->isLVal()) {
-      LLValue *ptr = DtoLVal(val);
-      assert(isaPointer(ptr));
-      ptr = DtoBitCast(ptr, DtoPtrToType(dgty));
-      IF_LOG Logger::cout() << "dg ptr: " << *ptr << '\n';
-      return new DLValue(to, ptr);
-    }
-    LLValue *dg = DtoRVal(val);
-    LLValue *context = gIR->ir->CreateExtractValue(dg, 0, ".context");
-    LLValue *funcptr = gIR->ir->CreateExtractValue(dg, 1, ".funcptr");
-    funcptr = DtoBitCast(funcptr, DtoType(dgty)->getContainedType(1));
-    LLValue *aggr = DtoAggrPair(context, funcptr);
-    IF_LOG Logger::cout() << "dg: " << *aggr << '\n';
-    return new DImValue(to, aggr);
-  }
-  if (from->ty == TY::Tpointer || from->ty == TY::Tclass ||
-      from->ty == TY::Taarray) {
-    Type *b = to->toBasetype();
-    assert(b->ty == TY::Tpointer || b->ty == TY::Tclass ||
-           b->ty == TY::Taarray);
-    LLValue *ptr = DtoBitCast(DtoRVal(val), DtoType(b));
-    return new DImValue(to, ptr);
-  }
-  if (from->ty == TY::Tsarray) {
-    assert(to->toBasetype()->ty == TY::Tsarray);
-    LLValue *ptr = DtoBitCast(DtoLVal(val), DtoPtrToType(to));
+  Type *tb = to->toBasetype();
+
+  if (val->isLVal()) {
+    auto ptr = DtoBitCast(DtoLVal(val), DtoPtrToType(tb));
     return new DLValue(to, ptr);
   }
-  assert(DtoType(from) == DtoType(to));
-  return new DImValue(to, DtoRVal(val));
+
+  if (auto slice = val->isSlice()) {
+    if (tb->ty == TY::Tarray) {
+      auto ptr = DtoBitCast(slice->getPtr(), DtoPtrToType(tb->nextOf()));
+      return new DSliceValue(to, slice->getLength(), ptr);
+    }
+  } else if (auto func = val->isFunc()) {
+    if (tb->ty == TY::Tdelegate) {
+      auto funcptr =
+          DtoBitCast(DtoRVal(func), DtoType(tb)->getContainedType(1));
+      return new DFuncValue(to, func->func, funcptr, func->vthis);
+    }
+  } else { // generic rvalue
+    LLValue *rval = DtoRVal(val);
+    LLType *tll = DtoType(tb);
+
+    if (rval->getType() == tll) {
+      return new DImValue(to, rval);
+    }
+    if (rval->getType()->isPointerTy() && tll->isPointerTy()) {
+      return new DImValue(to, DtoBitCast(rval, tll));
+    }
+    if (from->ty == TY::Tdelegate && tb->ty == TY::Tdelegate) {
+      LLValue *context = gIR->ir->CreateExtractValue(rval, 0, ".context");
+      LLValue *funcptr = gIR->ir->CreateExtractValue(rval, 1, ".funcptr");
+      funcptr = DtoBitCast(funcptr, tll->getContainedType(1));
+      return new DImValue(to, DtoAggrPair(context, funcptr));
+    }
+  }
+
+  error(loc, "ICE: unexpected type repaint from `%s` to `%s`", from->toChars(),
+        to->toChars());
+  fatal();
 }
 
 /******************************************************************************
@@ -905,7 +897,7 @@ void DtoVarDeclaration(VarDeclaration *vd) {
   if (isIrLocalCreated(vd)) {
     // Nothing to do if it has already been allocated.
   } else if (gIR->func()->sretArg &&
-             ((gIR->func()->decl->nrvo_can &&
+             ((gIR->func()->decl->isNRVO() &&
                gIR->func()->decl->nrvo_var == vd) ||
               (vd->isResult() && !isSpecialRefVar(vd)))) {
     // Named Return Value Optimization (NRVO):
@@ -1084,7 +1076,8 @@ LLValue *DtoRawVarDeclaration(VarDeclaration *var, LLValue *addr) {
  * INITIALIZER HELPERS
  ******************************************************************************/
 
-LLConstant *DtoConstInitializer(const Loc &loc, Type *type, Initializer *init) {
+LLConstant *DtoConstInitializer(const Loc &loc, Type *type, Initializer *init,
+                                const bool isCfile) {
   LLConstant *_init = nullptr; // may return zero
   if (!init) {
     if (type->toBasetype()->isTypeNoreturn()) {
@@ -1093,7 +1086,7 @@ LLConstant *DtoConstInitializer(const Loc &loc, Type *type, Initializer *init) {
       _init = LLConstant::getNullValue(ty);
     } else {
       IF_LOG Logger::println("const default initializer for %s", type->toChars());
-      Expression *initExp = defaultInit(type, loc);
+      Expression *initExp = defaultInit(type, loc, isCfile);
       _init = DtoConstExpInit(loc, type, initExp);
     }
   } else if (ExpInitializer *ex = init->isExpInitializer()) {
@@ -1101,7 +1094,7 @@ LLConstant *DtoConstInitializer(const Loc &loc, Type *type, Initializer *init) {
     _init = DtoConstExpInit(loc, type, ex->exp);
   } else if (ArrayInitializer *ai = init->isArrayInitializer()) {
     Logger::println("const array initializer");
-    _init = DtoConstArrayInitializer(ai, type);
+    _init = DtoConstArrayInitializer(ai, type, isCfile);
   } else if (init->isVoidInitializer()) {
     Logger::println("const void initializer");
     LLType *ty = DtoMemType(type);
@@ -1149,7 +1142,7 @@ LLConstant *DtoConstExpInit(const Loc &loc, Type *targetType, Expression *exp) {
     return llvm::Constant::getNullValue(targetLLType);
 
   // extend i1 to i8
-  if (llType == LLType::getInt1Ty(gIR->context())) {
+  if (llType->isIntegerTy(1)) {
     llType = LLType::getInt8Ty(gIR->context());
     val = llvm::ConstantExpr::getZExt(val, llType);
   }
@@ -1695,7 +1688,7 @@ llvm::Constant *buildStringLiteralConstant(StringExp *se, bool zeroTerm) {
   std::vector<LLConstant *> vals;
   vals.reserve(len);
   for (size_t i = 0; i < se->numberOfCodeUnits(); ++i) {
-    vals.push_back(LLConstantInt::get(ct, se->charAt(i), false));
+    vals.push_back(LLConstantInt::get(ct, se->getCodeUnit(i), false));
   }
   if (zeroTerm) {
     vals.push_back(LLConstantInt::get(ct, 0, false));
@@ -1859,7 +1852,7 @@ FuncDeclaration *getParentFunc(Dsymbol *sym) {
     if (auto fld = fd->isFuncLiteralDeclaration()) {
       if (fld->tok == TOK::function_)
         return nullptr;
-    } else if (fd->isStatic() || (!fd->isThis() && fd->linkage != LINK::d)) {
+    } else if (fd->isStatic() || (!fd->isThis() && fd->_linkage != LINK::d)) {
       return nullptr;
     }
   }
