@@ -32,13 +32,9 @@
 #include "llvm/Transforms/Instrumentation.h"
 #include "llvm/Transforms/IPO.h"
 #include "llvm/Transforms/IPO/PassManagerBuilder.h"
-#if LDC_LLVM_VER >= 800
 #include "llvm/Transforms/Instrumentation/MemorySanitizer.h"
 #include "llvm/Transforms/Instrumentation/ThreadSanitizer.h"
-#endif
-#if LDC_LLVM_VER >= 900
 #include "llvm/Transforms/Instrumentation/AddressSanitizer.h"
-#endif
 #if LDC_LLVM_VER >= 1000
 #include "llvm/Transforms/Instrumentation/SanitizerCoverage.h"
 #endif
@@ -94,11 +90,6 @@ static cl::opt<cl::boolOrDefault, false, opts::FlagParser<cl::boolOrDefault>>
         "cross-module-inlining", cl::ZeroOrMore, cl::Hidden,
         cl::desc("(*) Enable cross-module function inlining (default disabled)"));
 
-#if LDC_LLVM_VER < 900
-static cl::opt<bool> unitAtATime("unit-at-a-time", cl::desc("Enable basic IPO"),
-                                 cl::ZeroOrMore, cl::init(true));
-#endif
-
 static cl::opt<bool> stripDebug(
     "strip-debug", cl::ZeroOrMore,
     cl::desc("Strip symbolic debug information before optimization"));
@@ -136,19 +127,13 @@ bool willCrossModuleInline() {
   return enableCrossModuleInlining == llvm::cl::BOU_TRUE && willInline();
 }
 
-#if LDC_LLVM_VER >= 800 && LDC_LLVM_VER < 1000
+#if LDC_LLVM_VER < 1000
 llvm::FramePointer::FP whichFramePointersToEmit() {
   if (auto option = opts::framePointerUsage())
     return *option;
   return isOptimizationEnabled() ? llvm::FramePointer::None
                                  : llvm::FramePointer::All;
 }
-#elif LDC_LLVM_VER < 800
-bool willEliminateFramePointer() {
-  const llvm::cl::boolOrDefault disableFPElimEnum = opts::disableFPElim();
-  return disableFPElimEnum == llvm::cl::BOU_FALSE ||
-         (disableFPElimEnum == llvm::cl::BOU_UNSET && isOptimizationEnabled());
-}
 #endif
 
 bool isOptimizationEnabled() { return optimizeLevel != 0; }
@@ -197,11 +182,7 @@ static void addGarbageCollect2StackPass(const PassManagerBuilder &builder,
 static void addAddressSanitizerPasses(const PassManagerBuilder &Builder,
                                       PassManagerBase &PM) {
   PM.add(createAddressSanitizerFunctionPass());
-#if LDC_LLVM_VER >= 900
   PM.add(createModuleAddressSanitizerLegacyPassPass());
-#else
-  PM.add(createAddressSanitizerModulePass());
-#endif
 }
 
 static void addMemorySanitizerPass(const PassManagerBuilder &Builder,
@@ -209,14 +190,8 @@ static void addMemorySanitizerPass(const PassManagerBuilder &Builder,
   int trackOrigins = fSanitizeMemoryTrackOrigins;
   bool recover = false;
   bool kernel = false;
-#if LDC_LLVM_VER >= 900
   PM.add(createMemorySanitizerLegacyPassPass(
       MemorySanitizerOptions{trackOrigins, recover, kernel}));
-#elif LDC_LLVM_VER >= 800
-  PM.add(createMemorySanitizerLegacyPassPass(trackOrigins, recover, kernel));
-#else
-  PM.add(createMemorySanitizerPass());
-#endif
 
   // MemorySanitizer inserts complex instrumentation that mostly follows
   // the logic of the original code, but operates on "shadow" values.
@@ -233,11 +208,7 @@ static void addMemorySanitizerPass(const PassManagerBuilder &Builder,
 
 static void addThreadSanitizerPass(const PassManagerBuilder &Builder,
                                    PassManagerBase &PM) {
-#if LDC_LLVM_VER >= 800
   PM.add(createThreadSanitizerLegacyPassPass());
-#else
-  PM.add(createThreadSanitizerPass());
-#endif
 }
 
 static void addSanitizerCoveragePass(const PassManagerBuilder &Builder,
@@ -300,9 +271,6 @@ static void addOptimizationPasses(legacy::PassManagerBase &mpm,
   } else {
     builder.Inliner = createAlwaysInlinerLegacyPass();
   }
-#if LDC_LLVM_VER < 900
-  builder.DisableUnitAtATime = !unitAtATime;
-#endif
   builder.DisableUnrollLoops = optLevel == 0;
 
   builder.DisableUnrollLoops = (disableLoopUnrolling.getNumOccurrences() > 0)
@@ -469,9 +437,6 @@ void outputOptimizationSettings(llvm::raw_ostream &hash_os) {
   hash_os << disableSimplifyDruntimeCalls;
   hash_os << disableSimplifyLibCalls;
   hash_os << disableGCToStack;
-#if LDC_LLVM_VER < 900
-  hash_os << unitAtATime;
-#endif
   hash_os << stripDebug;
   hash_os << disableLoopUnrolling;
   hash_os << disableLoopVectorization;
