@@ -367,7 +367,6 @@ void DtoCheckPragma(PragmaDeclaration *decl, Dsymbol *s,
 
   case LLVMglobal_crt_ctor:
   case LLVMglobal_crt_dtor: {
-    const unsigned char flag = llvm_internal == LLVMglobal_crt_ctor ? 1 : 2;
     const int count = applyFunctionPragma(s, [=](FuncDeclaration *fd) {
       assert(fd->type->ty == TY::Tfunction);
       TypeFunction *type = static_cast<TypeFunction *>(fd->type);
@@ -378,9 +377,17 @@ void DtoCheckPragma(PragmaDeclaration *decl, Dsymbol *s,
               "the `%s` pragma is only allowed on `void` functions which take "
               "no arguments",
               ident->toChars());
-        fd->isCrtCtorDtor &= ~flag;
+        if (llvm_internal == LLVMglobal_crt_ctor) {
+          fd->isCrtCtor(false);
+        } else {
+          fd->isCrtDtor(false);
+        }
       } else {
-        fd->isCrtCtorDtor |= flag;
+        if (llvm_internal == LLVMglobal_crt_ctor) {
+          fd->isCrtCtor(true);
+        } else {
+          fd->isCrtDtor(true);
+        }
         fd->priority = std::atoi(arg1str);
       }
     });
