@@ -22,11 +22,7 @@ namespace llvm {
 // Auto-generate:
 // Attribute::AttrKind getAttrKindFromName(StringRef AttrName) { ... }
 #define GET_ATTR_KIND_FROM_NAME
-#if LDC_LLVM_VER < 700
-#include "llvm/IR/Attributes.gen"
-#else
 #include "llvm/IR/Attributes.inc"
-#endif
 }
 #endif
 
