@@ -130,9 +130,6 @@ void addOptimizationPasses(llvm::legacy::PassManagerBase &mpm,
   } else {
     builder.Inliner = llvm::createAlwaysInlinerLegacyPass();
   }
-#if LDC_LLVM_VER < 900
-  builder.DisableUnitAtATime = false;
-#endif
 
   builder.DisableUnrollLoops = (disableLoopUnrolling.getNumOccurrences() > 0)
                                    ? disableLoopUnrolling
