@@ -16,4 +16,4 @@ echo 'void main() {}' > "${src}"
 # Only compile, not link, since optlink can't handle long file names
 $DMD -m"${MODEL}" "${DFLAGS}" -c -of"${bin}" "${src}"
 
-rm -rf "${OUTPUT_BASE}"
+rm_retry -r "${OUTPUT_BASE}"
