@@ -10,3 +10,8 @@ long reg22344(adler, buf, len)
 {
     return 0;
 }
+
+// https://issues.dlang.org/show_bug.cgi?id=22896
+
+void fn(int);
+void fn(const int x);
