@@ -8,9 +8,18 @@ int test22597(const char *format, ...)
 {
     va_list va;
     __builtin_va_start(va,format);
+    va_list va2;
+    __builtin_va_copy(va2, va);
+    const char *s = __builtin_va_arg(va, const char *);
+    if (*s != 'h')
+    {
+        printf("test22597 failed `%c`\n", *s);
+        return 1;
+    }
     char buf[32];
-    int ret = vsprintf(buf, format, va);
+    int ret = vsprintf(buf, format, va2);
     __builtin_va_end(va);
+    __builtin_va_end(va2);
     return ret;
 }
 
